@@ -25,8 +25,8 @@
 #include "account.h"
 #include "file.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
