@@ -25,9 +25,9 @@
 #include "object.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QString>
-#include <QtCore/QUrl>
-#include <QtCore/QVariantMap>
+#include <QString>
+#include <QUrl>
+#include <QVariantMap>
 
 #include <QDateTime>
 
